<?php
/**
 * Gardener Lite functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Gardener Lite
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Gardener_Lite_Loader.php' );

$Gardener_Lite_Loader = new \WPTRT\Autoload\Gardener_Lite_Loader();

$Gardener_Lite_Loader->gardener_lite_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$Gardener_Lite_Loader->gardener_lite_register();

if ( ! function_exists( 'gardener_lite_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function gardener_lite_setup() {

		add_theme_support( 'woocommerce' );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "align-wide" );
		add_theme_support( "wp-block-styles" );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

        add_image_size('gardener-lite-featured-header-image', 2000, 660, true);

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary','gardener-lite' ),
	        'footer'=> esc_html__( 'Footer Menu','gardener-lite' ),
        ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'gardener_lite_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 50,
			'flex-width'  => true,
		) );

		add_editor_style( array( '/editor-style.css' ) );
		add_action('wp_ajax_gardener_lite_dismissable_notice', 'gardener_lite_dismissable_notice');
	}
endif;
add_action( 'after_setup_theme', 'gardener_lite_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function gardener_lite_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'gardener_lite_content_width', 1170 );
}
add_action( 'after_setup_theme', 'gardener_lite_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function gardener_lite_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'gardener-lite' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'gardener-lite' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Woocommerce Shop Page Sidebar', 'gardener-lite' ),
		'id'            => 'woocommerce-shop-page-sidebar',
		'description'   => '',
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Woocommerce Single Product Page Sidebar', 'gardener-lite' ),
		'id'            => 'woocommerce-single-product-page-sidebar',
		'description'   => '',
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Front Page Sidebar', 'gardener-lite' ),
		'id'            => 'front-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'gardener-lite' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'gardener-lite' ),
		'id'            => 'gardener-lite-footer1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 2', 'gardener-lite' ),
		'id'            => 'gardener-lite-footer2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 3', 'gardener-lite' ),
		'id'            => 'gardener-lite-footer3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'gardener_lite_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function gardener_lite_scripts() {

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

		wp_enqueue_style(
			'jost',
			wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Jost:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&family=Mulish:ital,wght@0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;0,1000;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900;1,1000&family=Titillium+Web:ital,wght@0,200;0,300;0,400;0,600;0,700;0,900;1,200;1,300;1,400;1,600;1,700&display=swap' ),
			array(),
			'1.0'
		);

	wp_enqueue_style( 'gardener-lite-block-editor-style', get_theme_file_uri('/assets/css/block-editor-style.css') );

	// load bootstrap css
    wp_enqueue_style( 'bootstrap-css',get_template_directory_uri() . '/assets/css/bootstrap.css');

    wp_enqueue_style( 'owl.carousel-css',get_template_directory_uri() . '/assets/css/owl.carousel.css');

	wp_enqueue_style( 'gardener-lite-style', get_stylesheet_uri() );
	require get_parent_theme_file_path( '/custom-option.php' );
	wp_add_inline_style( 'gardener-lite-style',$gardener_lite_theme_css );

	wp_style_add_data('gardener-lite-basic-style', 'rtl', 'replace');

	// fontawesome
	wp_enqueue_style( 'fontawesome-style',get_template_directory_uri().'/assets/css/fontawesome/css/all.css' );

    wp_enqueue_script('gardener-lite-theme-js',get_template_directory_uri() . '/assets/js/theme-script.js', array('jquery'), '', true );

    wp_enqueue_script('owl.carousel-js',get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'gardener_lite_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';


//  * Implement the Custom Header feature.

require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/*dropdown page sanitization*/
function gardener_lite_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/*checkbox sanitization*/
function gardener_lite_sanitize_checkbox( $input ) {
	// Boolean check
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function gardener_lite_sanitize_phone_number( $phone ) {
	return preg_replace( '/[^\d+]/', '', $phone );
}

function gardener_lite_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

function gardener_lite_sanitize_number_absint( $number, $setting ) {
	// Ensure $number is an absolute integer (whole number, zero or greater).
	$number = absint( $number );

	// If the input is an absolute integer, return it; otherwise, return the default
	return ( $number ? $number : $setting->default );
}

/*radio button sanitization*/
function gardener_lite_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gardener_lite_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

function gardener_lite_remove_sections( $wp_customize ) {
	$wp_customize->remove_control('display_header_text');
	$wp_customize->remove_setting('display_header_text');
	$wp_customize->remove_control('header_textcolor');
	$wp_customize->remove_setting('header_textcolor');
}
add_action( 'customize_register', 'gardener_lite_remove_sections');

/**
 * Get CSS
 */

function gardener_lite_getpage_css($hook) {
	wp_enqueue_script( 'gardener-lite-admin-script', get_template_directory_uri() . '/inc/admin/js/gardener-lite-admin-notice-script.js', array( 'jquery' ) );
    wp_localize_script( 'gardener-lite-admin-script', 'gardener_lite_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
	if ( 'appearance_page_gardener-lite-info' != $hook ) {
		return;
	}
	wp_enqueue_style( 'gardener-lite-demo-style', get_template_directory_uri() . '/assets/css/demo.css' );
}
add_action( 'admin_enqueue_scripts', 'gardener_lite_getpage_css' );

if ( ! defined( 'GARDENER_LITE_CONTACT_SUPPORT' ) ) {
define('GARDENER_LITE_CONTACT_SUPPORT',__('https://wordpress.org/support/theme/gardener-lite','gardener-lite'));
}
if ( ! defined( 'GARDENER_LITE_REVIEW' ) ) {
define('GARDENER_LITE_REVIEW',__('https://wordpress.org/support/theme/gardener-lite/reviews/#new-post','gardener-lite'));
}
if ( ! defined( 'GARDENER_LITE_LIVE_DEMO' ) ) {
define('GARDENER_LITE_LIVE_DEMO',__('https://www.themagnifico.net/demo/gardener-zone/','gardener-lite'));
}
if ( ! defined( 'GARDENER_LITE_GET_PREMIUM_PRO' ) ) {
define('GARDENER_LITE_GET_PREMIUM_PRO',__('https://www.themagnifico.net/themes/landscape-wordpress-theme/','gardener-lite'));
}
if ( ! defined( 'GARDENER_LITE_PRO_DOC' ) ) {
define('GARDENER_LITE_PRO_DOC',__('https://www.themagnifico.net/eard/wathiqa/gardener-zone-pro-doc/','gardener-lite'));
}
if ( ! defined( 'GARDENER_LITE_FREE_DOC' ) ) {
define('GARDENER_LITE_FREE_DOC',__('https://themagnifico.net/eard/wathiqa/gardener-lite-free-doc/','gardener-lite'));
}

add_action('admin_menu', 'gardener_lite_themepage');
function gardener_lite_themepage(){

	$gardener_lite_theme_test = wp_get_theme();

	$gardener_lite_theme_info = add_theme_page( __('Theme Options','gardener-lite'), __('Theme Options','gardener-lite'), 'manage_options', 'gardener-lite-info.php', 'gardener_lite_info_page' );
}

function gardener_lite_info_page() {
	$gardener_lite_user = wp_get_current_user();
	$gardener_lite_theme = wp_get_theme();
	?>
	<div class="wrap about-wrap gardener-lite-add-css">
		<div>
			<h1>
				<?php esc_html_e('Welcome To ','gardener-lite'); ?><?php echo esc_html( $gardener_lite_theme ); ?>
			</h1>
			<div class="feature-section three-col">
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Contact Support", "gardener-lite"); ?></h3>
						<p><?php esc_html_e("Thank you for trying Gardener Lite , feel free to contact us for any support regarding our theme.", "gardener-lite"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( GARDENER_LITE_CONTACT_SUPPORT ); ?>" class="button button-primary get">
							<?php esc_html_e("Contact Support", "gardener-lite"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Checkout Premium", "gardener-lite"); ?></h3>
						<p><?php esc_html_e("Our premium theme comes with extended features like demo content import , responsive layouts etc.", "gardener-lite"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( GARDENER_LITE_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
							<?php esc_html_e("Get Premium", "gardener-lite"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Review", "gardener-lite"); ?></h3>
						<p><?php esc_html_e("If You love Gardener Lite theme then we would appreciate your review about our theme.", "gardener-lite"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( GARDENER_LITE_REVIEW ); ?>" class="button button-primary get">
							<?php esc_html_e("Review", "gardener-lite"); ?>
						</a></p>
					</div>
				</div>
			</div>
		</div>
		<hr>

		<h2><?php esc_html_e("Free Vs Premium","gardener-lite"); ?></h2>
		<div class="gardener-lite-button-container">
			<a target="_blank" href="<?php echo esc_url( GARDENER_LITE_PRO_DOC ); ?>" class="button button-primary get">
				<?php esc_html_e("Checkout Documentation", "gardener-lite"); ?>
			</a>
			<a target="_blank" href="<?php echo esc_url( GARDENER_LITE_LIVE_DEMO ); ?>" class="button button-primary get">
				<?php esc_html_e("View Theme Demo", "gardener-lite"); ?>
			</a>
		</div>

		<table class="wp-list-table widefat">
			<thead class="table-book">
				<tr>
					<th><strong><?php esc_html_e("Theme Feature", "gardener-lite"); ?></strong></th>
					<th><strong><?php esc_html_e("Basic Version", "gardener-lite"); ?></strong></th>
					<th><strong><?php esc_html_e("Premium Version", "gardener-lite"); ?></strong></th>
				</tr>
			</thead>

			<tbody>
				<tr>
					<td><?php esc_html_e("Header Background Color", "gardener-lite"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Navigation Logo Or Text", "gardener-lite"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Hide Logo Text", "gardener-lite"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Premium Support", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Fully SEO Optimized", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Recent Posts Widget", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Easy Google Fonts", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Pagespeed Plugin", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Header Image On Front Page", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Show Header Everywhere", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Text On Header Image", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Full Width (Hide Sidebar)", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Upper Widgets On Front Page", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Replace Copyright Text", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Upper Widgets Colors", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Navigation Color", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Post/Page Color", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Blog Feed Color", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Footer Color", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Sidebar Color", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Background Color", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Importable Demo Content	", "gardener-lite"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
			</tbody>
		</table>
		<div class="gardener-lite-button-container">
			<a target="_blank" href="<?php echo esc_url( GARDENER_LITE_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
				<?php esc_html_e("Go Premium", "gardener-lite"); ?>
			</a>
		</div>
	</div>
	<?php
}

//Admin Notice For Getstart
function gardener_lite_ajax_notice_handler() {
    if ( isset( $_POST['type'] ) ) {
        $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
        update_option( 'dismissed-' . $type, TRUE );
    }
}

function gardener_lite_deprecated_hook_admin_notice() {

    $dismissed = get_user_meta(get_current_user_id(), 'gardener_lite_dismissable_notice', true);
    if ( !$dismissed) { ?>
        <div class="updated notice notice-success is-dismissible notice-get-started-class" data-notice="get_started" style="background: #f7f9f9; padding: 20px 10px; display: flex;">
	    	<div class="tm-admin-image">
	    		<img style="width: 100%;max-width: 320px;line-height: 40px;display: inline-block;vertical-align: top;border: 2px solid #ddd;border-radius: 4px;" src="<?php echo esc_url(get_stylesheet_directory_uri()) .'/screenshot.png'; ?>" />
	    	</div>
	    	<div class="tm-admin-content" style="padding-left: 30px; align-self: center">
	    		<h2 style="font-weight: 600;line-height: 1.3; margin: 0px;"><?php esc_html_e('Thank You For Choosing ', 'gardener-lite'); ?><?php echo wp_get_theme(); ?><h2>
	    		<p style="color: #3c434a; font-weight: 400; margin-bottom: 30px;"><?php _e('Get Started With Theme By Clicking On Getting Started.', 'gardener-lite'); ?><p>
	        	<a class="admin-notice-btn button button-primary button-hero" href="<?php echo esc_url( admin_url( 'themes.php?page=gardener-lite-info.php' )); ?>"><?php esc_html_e( 'Get started', 'gardener-lite' ) ?></a>
	        	<a class="admin-notice-btn button button-primary button-hero" target="_blank" href="<?php echo esc_url( GARDENER_LITE_FREE_DOC ); ?>"><?php esc_html_e( 'Documentation', 'gardener-lite' ) ?></a>
	        	<span style="padding-top: 15px; display: inline-block; padding-left: 8px;">
	        	<span class="dashicons dashicons-admin-links"></span>
	        	<a class="admin-notice-btn"	 target="_blank" href="<?php echo esc_url( GARDENER_LITE_LIVE_DEMO ); ?>"><?php esc_html_e( 'View Demo', 'gardener-lite' ) ?></a>
	        	</span>
	    	</div>
        </div>
    <?php }
}

add_action( 'admin_notices', 'gardener_lite_deprecated_hook_admin_notice' );

function gardener_lite_switch_theme() {
    delete_user_meta(get_current_user_id(), 'gardener_lite_dismissable_notice');
}
add_action('after_switch_theme', 'gardener_lite_switch_theme');
function gardener_lite_dismissable_notice() {
    update_user_meta(get_current_user_id(), 'gardener_lite_dismissable_notice', true);
    die();
}

/**
 * Enqueue S Header.
 */
function gardener_lite_sticky_header() {

	$gardener_lite_sticky_header = get_theme_mod('gardener_lite_sticky_header');

	$gardener_lite_custom_style= "";

	if($gardener_lite_sticky_header != true){

		$gardener_lite_custom_style .='.main-header{';

			$gardener_lite_custom_style .='position: static;';

		$gardener_lite_custom_style .='}';
	}

	wp_add_inline_style( 'gardener-lite-style',$gardener_lite_custom_style );

}
add_action( 'wp_enqueue_scripts', 'gardener_lite_sticky_header' );

/**
 * Enqueue theme color style.
 */
function gardener_lite_theme_color() {

    $gardener_lite_theme_color_css = '';
    $gardener_lite_theme_color = get_theme_mod('gardener_lite_theme_color');
    $gardener_lite_theme_color_2 = get_theme_mod('gardener_lite_theme_color_2');
    $gardener_lite_preloader_bg_color = get_theme_mod('gardener_lite_preloader_bg_color');
    $gardener_lite_preloader_dot_1_color = get_theme_mod('gardener_lite_preloader_dot_1_color');
    $gardener_lite_preloader_dot_2_color = get_theme_mod('gardener_lite_preloader_dot_2_color');
    $gardener_lite_logo_max_height = get_theme_mod('gardener_lite_logo_max_height');

	if(get_theme_mod('gardener_lite_logo_max_height') == '') {
		$gardener_lite_logo_max_height = '24';
	}
    if(get_theme_mod('gardener_lite_preloader_bg_color') == '') {
			$gardener_lite_preloader_bg_color = '#000';
		}
		if(get_theme_mod('gardener_lite_preloader_dot_1_color') == '') {
			$gardener_lite_preloader_dot_1_color = '#fff';
		}
		if(get_theme_mod('gardener_lite_preloader_dot_2_color') == '') {
			$gardener_lite_preloader_dot_2_color = '#036f38';
		}

	$gardener_lite_theme_color_css = '
	.custom-logo-link img{
			max-height: '.esc_attr($gardener_lite_logo_max_height).'px;
		 }
		#button,#button:hover,#button:active,.slider-box-btn a:hover,.team-btn a:hover,#top-slider .owl-nav i,.sidebar input[type="submit"],.sidebar button[type="submit"],span.onsale,.pro-button a,.woocommerce #respond input#submit,.woocommerce a.button,.woocommerce button.button,.woocommerce input.button,.woocommerce #respond input#submit.alt,.woocommerce a.button.alt,.woocommerce button.button.alt,.woocommerce input.button.alt,.pro-button a:hover,.woocommerce #respondinput#submit:hover,.woocommerce a.button:hover,.woocommerce button.button:hover,.woocommerce input.button:hover,.woocommerce #respond input#submit.alt:hover,.woocommerce a.button.alt:hover,.woocommerce button.button.alt:hover,.woocommerce input.button.alt:hover,.woocommerce .woocommerce-ordering select,.woocommerce-account .woocommerce-MyAccount-navigation ul li,.main-navigation .sub-menu,.main-navigation .sub-menu > li > a:hover,.main-navigation .sub-menu > li > a:focus,.post-navigation.nav-previous a:hover,.post-navigation .nav-next a:hover,.posts-navigation .nav-previous a:hover,.posts-navigation .nav-next a:hover,.navigation.pagination .nav-links a.current, .navigation.pagination .nav-links a:hover,.navigation.pagination .nav-links span.current,.navigation.pagination .nav-links span:hover,.comment-respond input#submit,#colophon,.sidebar h5,.sidebar .tagcloud a:hover,.toggle-nav i,.sidenav .closebtn,.top_header{
			background: '.esc_attr($gardener_lite_theme_color).';
		}
		h1,h2,h3,h4,h5,h6,a,.navbar-brand a,.navbar-brand p,.slider-box-btn a,.article-box a,a.btn-text,p.price,.woocommerce ul.products li.product .price,.woocommerce div.product p.price,.woocommerce div.product span.price,.woocommerce-message::before,.main-navigation .menu > li > a:hover,.sidebar ul li a:hover,.widget a:hover, .widget a:focus,.woocommerce-info::before,.main-navigation .menu > li > a{
			color: '.esc_attr($gardener_lite_theme_color).';
		}
		.postcat-name{
			color: '.esc_attr($gardener_lite_theme_color).'!important;
		}
		.user-account a{
			border-color: '.esc_attr($gardener_lite_theme_color).';
		}
		@media screen and (max-width: 1000px){
     .sidenav {
			 background: '.esc_attr($gardener_lite_theme_color_2).';
		 }
		.woocommerce-message,.woocommerce-info,.post-navigation .nav-previous a:hover,.post-navigation .nav-next a:hover,.posts-navigation .nav-previous a:hover,.posts-navigation .nav-next a:hover,.navigation.pagination .nav-links a.current, .navigation.pagination .nav-links a:hover,.navigation.pagination .nav-links span.current,.navigation.pagination .nav-links span:hover,.user-account a{
			border-color: '.esc_attr($gardener_lite_theme_color).';
		}
		.main-header{
			background: '.esc_attr($gardener_lite_theme_color_2).';
		}
		.loading{
			background-color: '.esc_attr($gardener_lite_preloader_bg_color).';
		 }
		 @keyframes loading {
		  0%,
		  100% {
		  	transform: translatey(-2.5rem);
		    background-color: '.esc_attr($gardener_lite_preloader_dot_1_color).';
		  }
		  50% {
		  	transform: translatey(2.5rem);
		    background-color: '.esc_attr($gardener_lite_preloader_dot_2_color).';
		  }
		}
	';
    wp_add_inline_style( 'gardener-lite-style',$gardener_lite_theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'gardener_lite_theme_color' );

// Change number or products per row to 3
add_filter('loop_shop_columns', 'gardener_lite_loop_columns');
if (!function_exists('gardener_lite_loop_columns')) {
	function gardener_lite_loop_columns() {
		$columns = get_theme_mod( 'gardener_lite_products_per_row', 3 );
		return $columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'gardener_lite_shop_per_page', 9 );
function gardener_lite_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'gardener_lite_product_per_page', 9 );
	return $cols;
}
