<?php
/**
 * Gardener Lite Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Gardener Lite
 */

if ( ! defined( 'GARDENER_LITE_CLUB_URL' ) ) {
define('GARDENER_LITE_CLUB_URL',__('https://www.themagnifico.net/themes/landscape-wordpress-theme/','gardener-lite'));
}
if ( ! defined( 'GARDENER_LITE_CLUB_BUY_TEXT' ) ) {
    define( 'GARDENER_LITE_CLUB_BUY_TEXT', __( 'Buy Gardener Pro','gardener-lite' ));
}

use WPTRT\Customize\Section\Gardener_Lite_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Gardener_Lite_Button::class );

    $manager->add_section(
        new Gardener_Lite_Button( $manager, 'gardener_lite_pro', [
            'title'       => __( 'Gardener Pro', 'gardener-lite' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'gardener-lite' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/landscape-wordpress-theme/', 'gardener-lite')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'gardener-lite-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'gardener-lite-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function gardener_lite_customize_register($wp_customize){

    // Pro Version
    class Gardener_Lite_Customize_Pro_Version extends WP_Customize_Control {
        public $type = 'pro_options';

        public function render_content() {
            echo '<span>For More <strong>'. esc_html( $this->label ) .'</strong>?</span>';
            echo '<a href="'. esc_url($this->description) .'" target="_blank">';
                echo '<span class="dashicons dashicons-info"></span>';
                echo '<strong> '. esc_html( GARDENER_LITE_CLUB_BUY_TEXT,'gardener-lite' ) .'<strong></a>';
            echo '</a>';
        }
    }

    // Custom Controls
    function Gardener_Lite_sanitize_custom_control( $input ) {
        return $input;
    }


    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    //Logo
    $wp_customize->add_setting('gardener_lite_logo_max_height',array(
        'default'   => '24',
        'sanitize_callback' => 'gardener_lite_sanitize_number_absint'
    ));
    $wp_customize->add_control('gardener_lite_logo_max_height',array(
        'label' => esc_html__('Logo Width','gardener-lite'),
        'section'   => 'title_tagline',
        'type'      => 'number'
    ));

    $wp_customize->add_setting('gardener_lite_logo_title', array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_logo_title',array(
        'label'          => __( 'Enable Disable Title', 'gardener-lite' ),
        'section'        => 'title_tagline',
        'settings'       => 'gardener_lite_logo_title',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_theme_description', array(
        'default' => false,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_theme_description',array(
        'label'          => __( 'Enable Disable Tagline', 'gardener-lite' ),
        'section'        => 'title_tagline',
        'settings'       => 'gardener_lite_theme_description',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_logo_title_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'gardener_lite_logo_title_color', array(
        'label'    => __('Site Title Color', 'gardener-lite'),
        'section'  => 'title_tagline'
    )));

    $wp_customize->add_setting('gardener_lite_logo_tagline_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'gardener_lite_logo_tagline_color', array(
        'label'    => __('Site Tagline Color', 'gardener-lite'),
        'section'  => 'title_tagline'
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_logo', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_logo', array(
        'section'     => 'title_tagline',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));

    // General Settings
     $wp_customize->add_section('gardener_lite_general_settings',array(
        'title' => esc_html__('General Settings','gardener-lite'),
        'priority'   => 30,
    ));

    $wp_customize->add_setting('gardener_lite_preloader_hide', array(
        'default' => '0',
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'gardener-lite' ),
        'section'        => 'gardener_lite_general_settings',
        'settings'       => 'gardener_lite_preloader_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting( 'gardener_lite_preloader_bg_color', array(
        'default' => '#000',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'gardener_lite_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','gardener-lite'),
        'section' => 'gardener_lite_general_settings',
        'settings' => 'gardener_lite_preloader_bg_color'
    )));

    $wp_customize->add_setting( 'gardener_lite_preloader_dot_1_color', array(
        'default' => '#fff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'gardener_lite_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','gardener-lite'),
        'section' => 'gardener_lite_general_settings',
        'settings' => 'gardener_lite_preloader_dot_1_color'
    )));

    $wp_customize->add_setting( 'gardener_lite_preloader_dot_2_color', array(
        'default' => '#036f38',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'gardener_lite_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','gardener-lite'),
        'section' => 'gardener_lite_general_settings',
        'settings' => 'gardener_lite_preloader_dot_2_color'
    )));


    $wp_customize->add_setting('gardener_lite_sticky_header', array(
        'default' => false,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_sticky_header',array(
        'label'          => __( 'Show Sticky Header', 'gardener-lite' ),
        'section'        => 'gardener_lite_general_settings',
        'settings'       => 'gardener_lite_sticky_header',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_scroll_hide', array(
        'default' => false,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_scroll_hide',array(
        'label'          => __( 'Show Theme Scroll To Top', 'gardener-lite' ),
        'section'        => 'gardener_lite_general_settings',
        'settings'       => 'gardener_lite_scroll_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_scroll_top_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'gardener_lite_sanitize_choices'
    ));
    $wp_customize->add_control('gardener_lite_scroll_top_position',array(
        'type' => 'radio',
        'section' => 'gardener_lite_general_settings',
        'choices' => array(
            'Right' => __('Right','gardener-lite'),
            'Left' => __('Left','gardener-lite'),
            'Center' => __('Center','gardener-lite')
        ),
    ) );

    // Product Columns
    $wp_customize->add_setting( 'gardener_lite_products_per_row' , array(
        'default'           => '3',
        'transport'         => 'refresh',
        'sanitize_callback' => 'gardener_lite_sanitize_select',
    ) );

    $wp_customize->add_control('gardener_lite_products_per_row', array(
       'label' => __( 'Product per row', 'gardener-lite' ),
       'section'  => 'gardener_lite_general_settings',
       'type'     => 'select',
       'choices'  => array(
           '2' => '2',
           '3' => '3',
           '4' => '4',
       ),
    ) );

    //Woocommerce shop page Sidebar
    $wp_customize->add_setting('gardener_lite_woocommerce_shop_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_woocommerce_shop_page_sidebar',array(
        'label'          => __( 'Hide Shop Page Sidebar', 'gardener-lite' ),
        'section'        => 'gardener_lite_general_settings',
        'settings'       => 'gardener_lite_woocommerce_shop_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_shop_page_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'gardener_lite_sanitize_choices'
    ));
    $wp_customize->add_control('gardener_lite_shop_page_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Shop Page Sidebar','gardener-lite'),
        'section' => 'gardener_lite_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','gardener-lite'),
            'Right Sidebar' => __('Right Sidebar','gardener-lite'),
        ),
    ) );

    //Woocommerce Single Product page Sidebar
    $wp_customize->add_setting('gardener_lite_woocommerce_single_product_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_woocommerce_single_product_page_sidebar',array(
        'label'          => __( 'Hide Single Product Page Sidebar', 'gardener-lite' ),
        'section'        => 'gardener_lite_general_settings',
        'settings'       => 'gardener_lite_woocommerce_single_product_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_single_product_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'gardener_lite_sanitize_choices'
    ));
    $wp_customize->add_control('gardener_lite_single_product_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Single Product Page Sidebar','gardener-lite'),
        'section' => 'gardener_lite_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','gardener-lite'),
            'Right Sidebar' => __('Right Sidebar','gardener-lite'),
        ),
    ) );

    // Related Product
    $wp_customize->add_setting('gardener_lite_woocommerce_related_product_show_hide', array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_woocommerce_related_product_show_hide',array(
        'label'          => __( 'Show / Hide Related product', 'gardener-lite' ),
        'section'        => 'gardener_lite_general_settings',
        'settings'       => 'gardener_lite_woocommerce_related_product_show_hide',
        'type'           => 'checkbox',
    )));


    // Pro Version
    $wp_customize->add_setting( 'pro_version_general_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_general_setting', array(
        'section'     => 'gardener_lite_general_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));

    // Theme Color
  $wp_customize->add_section('gardener_lite_color_option',array(
      'title' => esc_html__('Theme Color','gardener-lite'),
      'priority'   => 10
  ));

  $wp_customize->add_setting( 'gardener_lite_theme_color', array(
      'default' => '',
      'sanitize_callback' => 'sanitize_hex_color'
  ));
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'gardener_lite_theme_color', array(
      'label' => esc_html__('First Color Option','gardener-lite'),
      'section' => 'gardener_lite_color_option',
      'settings' => 'gardener_lite_theme_color'
  )));

  $wp_customize->add_setting( 'gardener_lite_theme_color_2', array(
      'default' => '',
      'sanitize_callback' => 'sanitize_hex_color'
  ));
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'gardener_lite_theme_color_2', array(
      'label' => esc_html__('Second Color Option','gardener-lite'),
      'section' => 'gardener_lite_color_option',
      'settings' => 'gardener_lite_theme_color_2'
  )));

   // Pro Version
    $wp_customize->add_setting( 'pro_version_theme_color', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_theme_color', array(
        'section'     => 'gardener_lite_color_option',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));


    // Top Header
    $wp_customize->add_section('gardener_lite_top_header',array(
        'title' => esc_html__('Top Header','gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_top_header_setting', array(
        'default' => 0,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_top_header_setting',array(
        'label'          => __( 'Enable Disable Top Header', 'gardener-lite' ),
        'section'        => 'gardener_lite_top_header',
        'settings'       => 'gardener_lite_top_header_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_mail_icon',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('gardener_lite_mail_icon',array(
      'label' => esc_html__('Email Icon','gardener-lite'),
      'section' => 'gardener_lite_top_header',
      'setting' => 'gardener_lite_mail_icon',
      'type'  => 'text',
      'default' => 'fas fa-envelope',
      'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fas fa-envelope','gardener-lite')
  ));

    $wp_customize->add_setting('gardener_lite_email',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_email'
    ));
    $wp_customize->add_control('gardener_lite_email',array(
        'label' => esc_html__('Add Email Address','gardener-lite'),
        'section' => 'gardener_lite_top_header',
        'setting' => 'gardener_lite_email',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('gardener_lite_phone_icon',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('gardener_lite_phone_icon',array(
      'label' => esc_html__('Phone Icon','gardener-lite'),
      'section' => 'gardener_lite_top_header',
      'setting' => 'gardener_lite_phone_icon',
      'type'  => 'text',
      'default' => 'fa fa-phone-square',
      'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fas fa-phone-square','gardener-lite')
  ));

    $wp_customize->add_setting('gardener_lite_phone',array(
        'default' => '',
        'sanitize_callback' => 'gardener_lite_sanitize_phone_number'
    ));
    $wp_customize->add_control('gardener_lite_phone',array(
        'label' => esc_html__('Add Phone Number','gardener-lite'),
        'section' => 'gardener_lite_top_header',
        'setting' => 'gardener_lite_phone',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('gardener_lite_location_icon',array(
      'default' => '',
      'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('gardener_lite_location_icon',array(
      'label' => esc_html__('Address Icon','gardener-lite'),
      'section' => 'gardener_lite_top_header',
      'setting' => 'gardener_lite_location_icon',
      'type'  => 'text',
      'default' => 'fas fa-map-marker-alt',
      'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fas fa-map-marker-alt','gardener-lite')
  ));

    $wp_customize->add_setting('gardener_lite_address',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('gardener_lite_address',array(
        'label' => esc_html__('Add Location Address','gardener-lite'),
        'section' => 'gardener_lite_top_header',
        'setting' => 'gardener_lite_address',
        'type'  => 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_top_header_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_top_header_setting', array(
        'section'     => 'gardener_lite_top_header',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));

    // Social Link
    $wp_customize->add_section('gardener_lite_social_link',array(
        'title' => esc_html__('Social Links','gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_facebook_url',array(
        'label' => esc_html__('Facebook Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_twitter_url',array(
        'label' => esc_html__('Twitter Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_intagram_url',array(
        'label' => esc_html__('Intagram Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_youtube_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_youtube_url',array(
        'label' => esc_html__('YouTube Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_pintrest_url',
        'type'  => 'url'
    ));

     // Pro Version
    $wp_customize->add_setting( 'pro_version_social_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_social_setting', array(
        'section'     => 'gardener_lite_social_link',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));

    //Slider
    $wp_customize->add_section('gardener_lite_top_slider',array(
        'title' => esc_html__('Slider Option','gardener-lite')
    ));

    $wp_customize->add_setting('gardener_lite_top_slider_setting', array(
        'default' => 0,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_top_slider_setting',array(
        'label'          => __( 'Enable Disable Slider', 'gardener-lite' ),
        'section'        => 'gardener_lite_top_slider',
        'settings'       => 'gardener_lite_top_slider_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_slider_loop', array(
        'default' => 1,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_slider_loop',array(
        'label'          => __( 'Enable Disable Slider Loop', 'gardener-lite' ),
        'section'        => 'gardener_lite_top_slider',
        'settings'       => 'gardener_lite_slider_loop',
        'type'           => 'checkbox',
    )));

    for ( $gardener_lite_count = 1; $gardener_lite_count <= 3; $gardener_lite_count++ ) {
        $wp_customize->add_setting( 'gardener_lite_top_slider_page' . $gardener_lite_count, array(
            'default'           => '',
            'sanitize_callback' => 'gardener_lite_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'gardener_lite_top_slider_page' . $gardener_lite_count, array(
            'label'    => __( 'Select Slide Page', 'gardener-lite' ),
            'section'  => 'gardener_lite_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    //Slider Image Opacity
    $wp_customize->add_setting('gardener_lite_slider_opacity_color',array(
      'default' => '',
      'sanitize_callback' => 'gardener_lite_sanitize_choices'
    ));

    $wp_customize->add_control( 'gardener_lite_slider_opacity_color', array(
    'label'       => esc_html__( 'Slider Image Opacity','gardener-lite' ),
    'section'     => 'gardener_lite_top_slider',
    'type'        => 'select',
    'choices' => array(
      '0' =>  esc_attr('0','gardener-lite'),
      '0.1' =>  esc_attr('0.1','gardener-lite'),
      '0.2' =>  esc_attr('0.2','gardener-lite'),
      '0.3' =>  esc_attr('0.3','gardener-lite'),
      '0.4' =>  esc_attr('0.4','gardener-lite'),
      '0.5' =>  esc_attr('0.5','gardener-lite'),
      '0.6' =>  esc_attr('0.6','gardener-lite'),
      '0.7' =>  esc_attr('0.7','gardener-lite'),
      '0.8' =>  esc_attr('0.8','gardener-lite'),
      '0.9' =>  esc_attr('0.9','gardener-lite')
    ),
    ));

    //Slider height
    $wp_customize->add_setting('gardener_lite_slider_img_height',array(
        'default'=> '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('gardener_lite_slider_img_height',array(
        'label' => __('Slider Height','gardener-lite'),
        'description'   => __('Add the slider height in px(eg. 500px).','gardener-lite'),
        'input_attrs' => array(
            'placeholder' => __( '500px', 'gardener-lite' ),
        ),
        'section'=> 'gardener_lite_top_slider',
        'type'=> 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_slider_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_slider_setting', array(
        'section'     => 'gardener_lite_top_slider',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));

    //Product
    $wp_customize->add_section('gardener_lite_new_product',array(
        'title' => esc_html__('Featured Product','gardener-lite'),
        'description' => esc_html__('Here you have to select product category which will display perticular new featured product in the home page.','gardener-lite')
    ));

    $wp_customize->add_setting('gardener_lite_new_product_setting', array(
        'default' => 0,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_new_product_setting',array(
        'label'          => __( 'Enable Disable Product', 'gardener-lite' ),
        'section'        => 'gardener_lite_new_product',
        'settings'       => 'gardener_lite_new_product_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_new_product_title',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('gardener_lite_new_product_title',array(
        'label' => esc_html__('Title','gardener-lite'),
        'section' => 'gardener_lite_new_product',
        'setting' => 'gardener_lite_new_product_title',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('gardener_lite_new_product_number',array(
        'default' => '',
        'sanitize_callback' => 'absint'
    ));
    $wp_customize->add_control('gardener_lite_new_product_number',array(
        'label' => esc_html__('No of Product','gardener-lite'),
        'section' => 'gardener_lite_new_product',
        'setting' => 'gardener_lite_new_product_number',
        'type'  => 'number'
    ));

    $gardener_lite_args = array(
       'type'                     => 'product',
        'child_of'                 => 0,
        'parent'                   => '',
        'orderby'                  => 'term_group',
        'order'                    => 'ASC',
        'hide_empty'               => false,
        'hierarchical'             => 1,
        'number'                   => '',
        'taxonomy'                 => 'product_cat',
        'pad_counts'               => false
    );
    $categories = get_categories( $gardener_lite_args );
    $cats = array();
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cats[$category->slug] = $category->name;
    }
    $wp_customize->add_setting('gardener_lite_new_product_category',array(
        'sanitize_callback' => 'gardener_lite_sanitize_select',
    ));
    $wp_customize->add_control('gardener_lite_new_product_category',array(
        'type'    => 'select',
        'choices' => $cats,
        'label' => __('Select Product Category','gardener-lite'),
        'section' => 'gardener_lite_new_product',
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_product_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_product_setting', array(
        'section'     => 'gardener_lite_new_product',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));


    // Footer
    $wp_customize->add_section('gardener_lite_site_footer_section', array(
        'title' => esc_html__('Footer', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_footer_bg_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'gardener_lite_footer_bg_image',array(
        'label' => __('Footer Background Image','gardener-lite'),
        'section' => 'gardener_lite_site_footer_section',
        'priority' => 1,
    )));

    $wp_customize->add_setting('gardener_lite_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('gardener_lite_footer_text_setting', array(
        'label' => __('Replace the footer text', 'gardener-lite'),
        'section' => 'gardener_lite_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));

    $wp_customize->add_setting('gardener_lite_show_hide_copyright',array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('gardener_lite_show_hide_copyright',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Copyright','gardener-lite'),
        'section' => 'gardener_lite_site_footer_section',
    ));

    $wp_customize->add_setting('gardener_lite_copyright_background_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'gardener_lite_copyright_background_color', array(
        'label'    => __('Copyright Background Color', 'gardener-lite'),
        'section'  => 'gardener_lite_site_footer_section',
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_footer_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_footer_setting', array(
        'section'     => 'gardener_lite_site_footer_section',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));

    // Post Settings
     $wp_customize->add_section('gardener_lite_post_settings',array(
        'title' => esc_html__('Post Settings','gardener-lite'),
        'priority'   =>40,
    ));

     $wp_customize->add_setting('gardener_lite_post_page_title',array(
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_post_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Title', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable title on post page.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_post_page_meta',array(
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_post_page_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Meta', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable meta on post page.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_post_page_thumb',array(
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_post_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Thumbnail', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable thumbnail on post page.', 'gardener-lite'),
    ));

    $wp_customize->add_setting( 'gardener_lite_post_page_image_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'gardener_lite_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'gardener_lite_post_page_image_border_radius', array(
        'label'       => esc_html__( 'Post Page Image Border Radius','gardener-lite' ),
        'section'     => 'gardener_lite_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting('gardener_lite_post_page_btn',array(
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_post_page_btn',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Button', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable button on post page.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_single_post_thumb',array(
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_single_post_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Thumbnail', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable post thumbnail on single post.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_single_post_meta',array(
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_single_post_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Meta', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable single post meta such as post date, author, category, comment etc.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_single_post_title',array(
            'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_single_post_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Title', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable title on single post.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_single_post_tags',array(
            'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_single_post_tags',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Tags', 'gardener-lite'),
        'section'     => 'gardener_lite_post_settings',
        'description' => esc_html__('Check this box to enable tags on single post.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_single_post_navigation_show_hide',array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('gardener_lite_single_post_navigation_show_hide',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Post Navigation','gardener-lite'),
        'section' => 'gardener_lite_post_settings',
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_post_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_post_setting', array(
        'section'     => 'gardener_lite_post_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));

    // Page Settings
    $wp_customize->add_section('gardener_lite_page_settings',array(
        'title' => esc_html__('Page Settings','gardener-lite'),
        'priority'   =>50,
    ));

    $wp_customize->add_setting('gardener_lite_single_page_title',array(
            'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_single_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Title', 'gardener-lite'),
        'section'     => 'gardener_lite_page_settings',
        'description' => esc_html__('Check this box to enable title on single page.', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_single_page_thumb',array(
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('gardener_lite_single_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Thumbnail', 'gardener-lite'),
        'section'     => 'gardener_lite_page_settings',
        'description' => esc_html__('Check this box to enable page thumbnail on single page.', 'gardener-lite'),
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_single_page_setting', array(
        'sanitize_callback' => 'Gardener_Lite_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Gardener_Lite_Customize_Pro_Version ( $wp_customize,'pro_version_single_page_setting', array(
        'section'     => 'gardener_lite_page_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'gardener-lite' ),
        'description' => esc_url( GARDENER_LITE_CLUB_URL ),
        'priority'    => 100
    )));
}
add_action('customize_register', 'gardener_lite_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function gardener_lite_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function gardener_lite_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function gardener_lite_customize_preview_js(){
    wp_enqueue_script('gardener-lite-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'gardener_lite_customize_preview_js');

/*
** Load dynamic logic for the customizer controls area.
*/
function gardener_lite_panels_js() {
    wp_enqueue_style( 'gardener-lite-customizer-layout-css', get_theme_file_uri( '/assets/css/customizer-layout.css' ) );
    wp_enqueue_script( 'gardener-lite-customize-layout', get_theme_file_uri( '/assets/js/customize-layout.js' ), array(), '1.2', true );
}
add_action( 'customize_controls_enqueue_scripts', 'gardener_lite_panels_js' );
